-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local L = addonTable.L
local C = addonTable.C

local min, abs = math.min, math.abs

local addon = PriorityList
addon.Dialogs = {}
local dialogs = addon.Dialogs
local chars = addon.CharFunctions
local items = addon.ItemFunctions
local constructors = addon.Constructors


-- Confirm Dialog
 StaticPopupDialogs["PL_ConfirmDialog"] = {
  preferredIndex = 3,
  text    = L["confirm"],
  button1 = OKAY,
  button2 = CANCEL,
  OnAccept = function(self,data,data2)
   data2()
  end,
  OnShow = function (self)
   --
  end,
 hideOnEscape = true,
 whileDead = true,
 hasEditBox = false,
 timeout = 0,
}


-- Character Add/Rename and ItemID Change Dialogs
local function editboxaccept(self, data, data2, data3, s)

 local function FilterString(str, pat)
  local _, _, result = string.find(str, "(%S+)")
  if result then result = string.gsub(result, pat, "") end
  return result
 end

 self:Hide()
 if data == "add" then
  local tmp = FilterString(s, "%d")
  if tmp then
   chars:New(tmp, true)
  end
  
 elseif data == "rename" and data2 then
  local tmp = FilterString(s, "%d")
  if tmp then
   chars:Rename(data2, tmp, true)
  end

 elseif data == "changeid" and data2 and data3 then
  local tmp = FilterString(s,"%D")
  if PLWish_List[data2] and tmp then
   local itemID = tonumber(data3)
   local tmp_pos = PriorityList:GetItemPos(data2,itemID)
   if not PriorityList:TableMatch(PLWish_List[data2],tonumber(tmp),true) then
    PriorityList:DeleteItem(itemID,false,true,data2)
    if not PriorityList:IsLooted(itemID) then
     PriorityList:AddItem(data2,tonumber(tmp),true,tmp_pos)
    else
     PriorityList:AddItem(data2,-tonumber(tmp),true,tmp_pos)
    end
   end
  end

 elseif data == "export" then
  local tmp = FilterString(s,"%d")
  if tmp then
   PriorityList:SendCommMessage("PriorityList", "::msg:request"..PriorityList.version, "WHISPER", tmp)
   PriorityList:StartExportTimer()
  end
 end
end

StaticPopupDialogs["PL_EditBoxDialog"] = {
 preferredIndex = 3,
 text           = "",
 button1        = OKAY,
 button2        = CANCEL,
 hideOnEscape   = true,
 whileDead      = true,
 hasEditBox     = true,
 timeout        = 0,
 OnAccept = function(self)
  			 editboxaccept(self, self.data, self.data2, self.data3, self.editBox:GetText())
            end,

 EditBoxOnTextChanged = function (self)
                         local s = self:GetText()
                         if s == "" or s:find("(%d+)") then
                          self:GetParent().button1:Disable()
                         else
                          self:GetParent().button1:Enable()
                         end
                        end,
						
 EditBoxOnEnterPressed =  function(self,data,data2)
                           local p = self:GetParent()
                           editboxaccept(p, p.data, p.data2, p.data3, self:GetText())
                          end,
						 
 EditBoxOnEscapePressed = function(self)
                           self:GetParent():Hide()
	                      end,
						  
 OnShow = function (self)
           self.editBox:SetText("")
           self.editBox:SetFocus()
           self.button1:Disable()
          end,
}

function dialogs:NewChar()
 if addon:IsSuperUser() then
  local dialog = StaticPopup_Show("PL_EditBoxDialog")
  if dialog then
   dialog.data = "add"
   dialog.data2 = ""
   dialog.text:SetText(L["new_char"])
  end
 else
  local p = UnitName("player")
  if not PLWish_List[p] then
   chars:New(p, true)
  end
 end
end

function dialogs:RenameChar(name)
 if not addon:IsSuperUser() then return end

 local dialog = StaticPopup_Show("PL_EditBoxDialog")
 if dialog then
  dialog.data = "rename"
  dialog.data2 = name
  dialog.data3 = ""
  dialog.text:SetText(L["rename_char"].." ("..name..")")
  dialog.editBox:SetText(name)
 end
end

function dialogs:Confirm(func, override, text)
 if pl_options["confirm_edit"] or override then -- confirm dialog
  local dialog = StaticPopup_Show("PL_ConfirmDialog")
  if dialog then
   if text then dialog.text:SetText(text) end
   dialog.data2 = func
  end
 else
  func()
 end
end

-- loading progress bar dialog
local dlg_load
function dialogs:Load_Init(max, text, exitfunc)
 if not dlg_load then
  dlg_load = CreateFrame("Frame", "PL3LoadDialog", UIParent)
  constructors:SetupTexture(dlg_load, 0,0,0,1)
  dlg_load:EnableMouse(true)
  dlg_load:SetFrameStrata("DIALOG")
  dlg_load:SetPoint("CENTER")
  dlg_load:SetSize(300,90)
  dlg_load:SetBackdrop(constructors.frame_backdrop)
  dlg_load:SetBackdropBorderColor(1,1,1,1)
  -- title
  dlg_load.title = dlg_load:CreateFontString()
  dlg_load.title:SetFont("Fonts\\ARIALN.ttf", 14, "")
  dlg_load.title:SetPoint("TOPLEFT", dlg_load, "TOPLEFT", 5, -5)
  -- progress bar
  dlg_load.progressbar = CreateFrame("Frame", "PL3LoadDialogProgressBar", dlg_load)
  constructors:SetupTexture(dlg_load.progressbar, 1,1,1,1)
  dlg_load.progressbar:SetPoint("TOPLEFT", dlg_load, "TOPLEFT", 10, -30)
  dlg_load.progressbar:SetHeight(20)
  dlg_load.progressbar.targetWidth = 0
  dlg_load.progressbar:SetScript("OnUpdate", function(self)
   local w = self:GetWidth()
   if w ~= self.targetWidth then
    local step = min(abs(w - self.targetWidth), 4)
    self:SetWidth(w + (w < self.targetWidth and step or -step))
   end
  end)
  -- cancel button
  dlg_load.btncancel = constructors:RectButton("PL3LoadDialogBtnCancel", dlg_load)
  dlg_load.btncancel:SetPoint("BOTTOM", dlg_load, "BOTTOM", 0, 5)
  dlg_load.btncancel:SetSize(75,25)
  dlg_load.btncancel:SetScript("OnMouseUp", function()
   if dlg_load.exitfunc then dlg_load.exitfunc() end
   dialogs:Load_Finalize()
  end)
 end
 dlg_load.exitfunc = exitfunc
 dlg_load.btncancel:SetText(CANCEL)
 dlg_load.progressbar:SetWidth(5)
 dlg_load.progress = 0
 dlg_load.max = max or 0
 dlg_load.text = text or ""
 dlg_load.title:SetText(text)
 dlg_load:Show()
end

-- /run PriorityList.Dialogs:Load_SetProgress(2)
function dialogs:Load_SetProgress(value)
 dlg_load.progress = value
 local percent = (value * 100 / dlg_load.max) / 100
 local r = (255 * (1 - percent)) / 100
 local g = (255 * percent) / 100
 dlg_load.progressbar.tex:SetTexture(r,g,0,1)
 --dlg_load.progressbar:SetWidth(280 * percent)
 dlg_load.progressbar.targetWidth = 280 * percent
 dlg_load.title:SetText(dlg_load.text.." "..value.." / "..dlg_load.max)
 if dlg_load.progress >= dlg_load.max then
  dlg_load.btncancel:SetText(DONE)
 end
end

function dialogs:Load_Finalize()
 dlg_load.progressbar.targetWidth = 0
 dlg_load.progressbar:SetWidth(0)
 dlg_load.progress = 0
 dlg_load.max = 0
 dlg_load:Hide()
end
-- Load End

-- Looted Flags dialog
local dlg_looted
local function dlg_looted_init()
 dlg_looted = CreateFrame("Frame", "PLLootedFlagsDialog", UIParent)
 constructors:SetupTexture(dlg_looted, 0,0,0,1)
 dlg_looted:SetSize(300,250)
 dlg_looted:SetPoint("CENTER")
 dlg_looted:SetMovable(true)
 dlg_looted:EnableMouse(true)
 dlg_looted:SetFrameStrata("DIALOG")
 dlg_looted:RegisterForDrag("LeftButton")
 dlg_looted:SetScript("OnDragStart", function(self) self:StartMoving() end)
 dlg_looted:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
 dlg_looted:SetBackdrop(constructors.frame_backdrop)
 dlg_looted:SetBackdropColor(0,0,0,1)
 dlg_looted:SetBackdropBorderColor(0.1,0.3,0.4,1)
 
 -- groupbox
 local grp = constructors:Groupbox(dlg_looted, nil, 1, 1, L["looted"])
 grp:SetPoint("TOPLEFT", dlg_looted, "TOPLEFT", 15, -15)
 grp:SetPoint("BOTTOMRIGHT", dlg_looted, "BOTTOMRIGHT", -15, 40)
 dlg_looted.title = grp.text
 
 -- looted checkbox
 local f = constructors:Checkbox(grp, 150, L["looted"])
 f:SetPoint("TOPLEFT", grp, "TOPLEFT", 5, -2)
 dlg_looted.chk_looted = f
 
 -- bonus checkboxes
 for i = 1,C.numBonuses do
  f = constructors:Checkbox(grp, 150, L["bonus"..i])
  f:SetPoint("TOP", dlg_looted.chk_looted, "BOTTOM", 0, -5 -20 * (i - 1))
  dlg_looted["chk_bonus"..i] = f
 end 
 
 -- personal checkbox
 local f = constructors:Checkbox(grp, 150, L["personal"])
 f:SetPoint("BOTTOMLEFT", grp, "BOTTOMLEFT", 5, 2)
 dlg_looted.chk_personal = f

 -- ok button
 dlg_looted.btncancel = constructors:RectButton("PL3LootedFlagsDialogBtnOk", dlg_looted)
 dlg_looted.btncancel:SetPoint("BOTTOMLEFT", dlg_looted, "BOTTOMLEFT", 10, 5)
 dlg_looted.btncancel:SetSize(75,25)
 dlg_looted.btncancel:SetText(OKAY)
 dlg_looted.btncancel:SetScript("OnMouseUp", function()
   local name, diff, itemID = dlg_looted.name, dlg_looted.difficulty, dlg_looted.itemID
   if PLWish_List[name] then
    local looted = dlg_looted.data
	local isLootedSet = dlg_looted.chk_looted:GetChecked()
	
	if not isLootedSet then
	 chars:UnsetLooted(name, itemID, diff, true)
	 dlg_looted:Hide()
	 return
	end
	
	local bonuses = dlg_looted.bonuses
	local personal = dlg_looted.chk_personal:GetChecked()

	for i = 1,C.numBonuses do
	 bonuses[i] = dlg_looted["chk_bonus"..i]:GetChecked()
	end

	if not looted then
	 local link = items:GenerateLink(itemID, name, nil, diff, bonuses)
	 chars:SetLooted(name, link, true, personal)
	else  -- check if there is any difference with the previous looted item
	 local old_bonuses = dlg_looted.old_bonuses
	 for i = 1,C.numBonuses do
	  if old_bonuses and old_bonuses[i] ~= bonuses[i] then
 	   -- there is a difference, generate a new itemlink
	   local link = items:GenerateLink(itemID, name, nil, diff, bonuses)
	   looted.link = link
	  end
	 end
	 looted.personal = personal
	 looted.time = time()
	 addon:Refresh()
	end
   end
   dlg_looted:Hide()
  end)
 
 -- cancel button
 dlg_looted.btncancel = constructors:RectButton("PL3LootedFlagsDialogBtnCancel", dlg_looted)
 dlg_looted.btncancel:SetPoint("BOTTOMRIGHT", dlg_looted, "BOTTOMRIGHT", -10, 5)
 dlg_looted.btncancel:SetSize(75,25)
 dlg_looted.btncancel:SetText(CANCEL)
 dlg_looted.btncancel:SetScript("OnMouseUp", function() dlg_looted:Hide() end)
 dlg_looted.data = {}
 dlg_looted.bonuses = {}
end

function dialogs:LootedFlags(name, difficulty, itemID)
 if not name then return end
 if not dlg_looted then dlg_looted_init() end

 dlg_looted.name = name
 dlg_looted.difficulty = difficulty
 dlg_looted.itemID = itemID
 dlg_looted.title:SetText(name.." (#"..(itemID or "")..")")
 
 dlg_looted.data  = chars:GetLootedItem(name, difficulty, itemID)
 dlg_looted.old_bonuses = dlg_looted.data and items:ExtractBonuses(dlg_looted.data.link)
 
 dlg_looted.chk_looted:SetChecked(dlg_looted.data ~= nil)
 dlg_looted.chk_personal:SetChecked(dlg_looted.data and dlg_looted.data.personal or false)
 for i = 1,C.numBonuses do
  dlg_looted["chk_bonus"..i]:SetChecked(dlg_looted.data and dlg_looted.old_bonuses[i] or false)
 end
 dlg_looted:Show()
end

-- Looted End
