-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

-- tab 1

local addonName, addonTable = ...
local L = addonTable.L
local C = addonTable.C
local T = addonTable.T
local AddColor = addonTable.AddColor

local addon = PriorityList
local menus = addon.MenuFunctions
local items = addon.ItemFunctions
local constructors = addon.Constructors
local dialogs = addon.Dialogs
local chars = addon.CharFunctions
local comm = addon.CommFunctions

local dd_char, dd_difficulty

local function onShow()
 if not addon:IsSuperUser() then
  PLWLBtnExport1:Hide()
 else
  PLWLBtnExport1:Show()
 end
 dd_char:SetParent(PLTabFrame1)
 dd_char:Show()
 PLListbox:Show()
 PLWLBtnList1:SetParent(PLTabFrame1)
 PLWLBtnList2:SetParent(PLTabFrame1)
 PLWLBtnList3:SetParent(PLTabFrame1)
 PLWLBtnList1:SetPoint("LEFT", dd_char, "RIGHT", 20, 0)
end
 
local function onHide()

end

function addon.eventPulse1(event, ...)

end

local function updateListButton(f, list, index)

 if index > #list then return end

 f.t = "item"

 local itemID = list[index]
 local name, link, quality, _, _, _, _, _, equipSlot, texture = items:GetItemInfo(itemID)
 
 f.s_bottomleft:SetText("")
 f.s_topright:SetText("")
 f.s_bottomright:SetText("")
 f.s_center:SetText("")
 f.centericon:Hide()
 f.background:SetVertexColor(0,0,0,0)
 f.itemID = itemID
 local looted = chars:GetLootedItem(addon.sel_char, addon.sel_difficulty, itemID)
 local bonuses
 if name and looted then 
  link = looted.link
  bonuses = items:ExtractBonuses(link)
  if looted.personal then
   f.background:SetVertexColor(0.2,1,0.6,0.1)
  else
   f.background:SetVertexColor(0.2,0.6,1,0.1)
  end
 end
 if not link then
  f.lefticon:SetTexture("Interface\\ICONS\\Ability_Mage_TimeWarp")
  f.s_topleft:SetText(AddColor(L["receiving_item_info"], "GOLD"))
 else
  f.link = items:GenerateLink(itemID, name, quality, addon.sel_difficulty, bonuses)
  f.lefticon:SetTexture(texture)
  local bns = items:GetBonusString(bonuses, true)
  f.s_topright:SetText((looted and AddColor(L["looted"]..(bns ~= "" and " -"..bns or ""), "LIGHT_BLUE") or ""))
  local _,_,_,c = GetItemQualityColor(quality or 1)
  f.s_topleft:SetText((c and ("|c"..c) or "")..name.."|r")
  local prio = addon.prio[addon.sel_difficulty][itemID]
  local info = ""
  if prio then
   local last_prio
   for k,v in pairs(prio) do
    local list = math.ceil(v.prio / C.PRIO_GAP)
	local isLooted = chars:GetLootedItem(v.name, addon.sel_difficulty, itemID)
	local s = isLooted and AddColor(--[[v.prio..]](pl_options["short_looted_names"] and v.name:sub(1,4) or v.name), "LIGHT_BLUE") or AddColor(v.name, C.list_color[list])
    if last_prio and last_prio == v.prio then
	 info = info..AddColor("\\", "LIGHT_GREEN")..s
	else
     info = info..(k > 1 and " " or "")..s
	end
	last_prio = v.prio
   end
  end
  f.s_bottomleft:SetText(info)
  f.s_bottomright:SetText("")
 end

 return true
end

function addon.listboxUpdate1(self)
 local offset  = HybridScrollFrame_GetOffset(self)
 local buttons = self.buttons
 local height  = 30

 local list = chars:GetList(addon.sel_char, addon.sel_list, addon.sel_difficulty)

 for i = 1, #buttons do
  local index = offset + i
  if list and updateListButton(buttons[i], list, index) then
   buttons[i]:Show()
  else
   buttons[i]:Hide()
  end
 end
 
 HybridScrollFrame_Update(self, height * (list and #list or 0), height)
end

function addon.buttonDragStart1(self)
 PickupItem(self.link or 1)
 if self.itemID and not IsControlKeyDown() then
  chars:DeleteItem(addon.sel_char, self.itemID, addon.sel_list, addon.sel_difficulty, true)
 end
end

function addon.listboxDragReceive1(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  chars:AddItem(addon.sel_char, itemID, addon.sel_list, addon.sel_difficulty, true)
  ClearCursor()
 end
end

function addon.listboxMouseUp1(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  addon.listboxDragReceive1(self)
 end
end

function addon.buttonDragReceive1(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  local pos = self.index + HybridScrollFrame_GetOffset(PLListbox)
  chars:AddItem(addon.sel_char, itemID, addon.sel_list, addon.sel_difficulty, true, pos)
  ClearCursor()
 end
end

function addon.buttonMouseUp1(self, button)
 if button == "LeftButton" then
  if IsShiftKeyDown() then
   -- link
  elseif IsAltKeyDown() and self.itemID then
   dialogs:LootedFlags(addon.sel_char, addon.sel_difficulty, self.itemID)
  else
   addon.buttonDragReceive1(self)
  end
 elseif button == "RightButton" and self.itemID and IsControlKeyDown() then
  chars:DeleteItem(addon.sel_char, self.itemID, addon.sel_list, addon.sel_difficulty, true)
 end
end

function addon.createTab1()
 local f = CreateFrame("Frame", "PLTabFrame1", PLMainframe)
 f:SetPoint("TOPLEFT", PLMainframeTabAnchor, "TOPLEFT")
 f:SetPoint("BOTTOMRIGHT", PLMainframe, "BOTTOMRIGHT", -30, 60)
 f:SetScript("OnShow", onShow)
 f:SetScript("OnHide", onHide)
 
  -- characters dropdown
 f = constructors:DropDown("PLDDCharacters", PLTabFrame1)
 f:SetPoint("TOPLEFT", PLTabFrame1, "TOPLEFT", 10, -40)
 f.lbl = f:CreateFontString()
 f.lbl:SetFont("Fonts\\ARIALN.ttf", 12, "")
 f.lbl:SetPoint("BOTTOM", f, "TOP", 0, 25)
 f.lbl:SetText(CHARACTER)
 menus.Init_CharSelect(f)
 dd_char = f

 -- new char button
 f = constructors:RectButton("PLTab1NewCharBtn", PLTabFrame1)
 f:SetPoint("BOTTOMLEFT", dd_char, "TOPLEFT", 1, 2)
 f:SetSize(40,20)
 f:SetText(NEW)
 f:SetScript("OnClick", function()
  dialogs:NewChar()
 end)

 -- rename char button
 f = constructors:RectButton("PLTab1RenCharBtn", PLTabFrame1)
 f:SetPoint("LEFT", PLTab1NewCharBtn, "RIGHT", 10, 0)
 f:SetSize(40,20)
 f:SetText(PET_RENAME)
 f:SetScript("OnClick", function()
  if PLWish_List[addon.sel_char] then
   dialogs:RenameChar(addon.sel_char)
  end
 end)

 -- delete char button
 f = constructors:RectButton("PLTab1DelCharBtn", PLTabFrame1)
 f:SetPoint("LEFT", PLTab1RenCharBtn, "RIGHT", 10, 0)
 f:SetSize(40,20)
 f:SetText(CALENDAR_DELETE_EVENT)
 f:SetScript("OnClick", function()
  if PLWish_List[addon.sel_char] then
   chars:Delete(addon.sel_char, true)
  end
 end)

 -- list buttons
 local function btnlist_onclick(self)
  local list = string.gsub(self:GetName(), "PLWLBtnList", "")
  list = tonumber(list)
  addon:EventPulse("select_list", list)
  addon:Refresh()
 end
 
 -- 1
 f = constructors:SquareButton("PLWLBtnList1", PLTabFrame1)
 f:SetSize(50,35)
 f:SetPoint("LEFT", dd_char, "RIGHT", 20, 0)
 f:SetText(L["list1"])
 f:SetScript("OnClick", btnlist_onclick)
 -- 2
 f = constructors:SquareButton("PLWLBtnList2", PLTabFrame1)
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLWLBtnList1, "RIGHT", 10, 0)
 f:SetText(L["list2"])
 f:SetScript("OnClick", btnlist_onclick)
 -- 3
 f = constructors:SquareButton("PLWLBtnList3", PLTabFrame1)
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLWLBtnList2, "RIGHT", 10, 0)
 f:SetText(L["list3"])
 f:SetScript("OnClick", btnlist_onclick)

 -- export button
 f = constructors:RectButton("PLWLBtnExport1", PLTabFrame1)
 f:SetSize(75,25)
 f:SetPoint("LEFT", PLWLBtnList3, "RIGHT", 50, 0)
 f:SetText(L["export_all"])
 f:SetScript("OnClick", function() comm:LinkToChat("all") end)
 
-- export button
 f = constructors:RectButton("PLWLBtnExport2", PLTabFrame1)
 f:SetSize(75,25)
 f:SetPoint("LEFT", PLWLBtnExport1, "RIGHT", 10, 0)
 f:SetText(L["export_char"])
 f:SetScript("OnClick", function() comm:LinkToChat(addon.sel_char) end)
 
 PLTabFrame1:Hide()
end