-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local L = addonTable.L
local AddColor = addonTable.AddColor

local addon = PriorityList
local serializer = addon.Serializer

-- ^C char
-- ^L list
-- ^D diff
-- ^I list itemID
-- ^J looted itemID
-- ^K link
-- ^T time
-- ^P personal

function serializer:packList(name, diff)
 if not PLWish_List[name] then return "" end
 
 local result = "^C"..name.."^D"..diff

 for list = 1,3 do
  local wl = PLWish_List[name][diff].lists[list]
  result = result.."^L"..list
  for i = 1,#wl do
   result = result.."^I"..wl[i]
  end
 end

 return result
end

function serializer:packLists(name)
 if not PLWish_List[name] then return "" end
 local result = ""
 for i = 1,3 do
  result = result..serializer:packList(name, i)
 end

 return result.."^"
end

function serializer:packLooted(name)
 if not PLWish_List[name] then return "" end
 local result = ""
 for diff = 1,3 do
  result = result.."^C"..name.."^D"..diff
  for k,v in pairs(PLWish_List[name][diff].looted) do
   if v.link and v.time then
    result = result.."^J"..k.."^K"..v.link.."^T"..v.time..(v.personal and "^P" or "")
   end
  end
 end
 
 return result.."^"
end

-- unpack
local function read(s)
 local _,j = strfind(s, "(^)")
 return string.sub(s, 1, j - 1)
end

function serializer:unpack(sender, arg)
 if not addon.import_list[sender] then addon.import_list[sender] = {} end
 
 if #arg < 2 then return "" end
 
 local t = addon.import_list[sender]
 
 local cur, lastcur = "", ""
 local name, diff, list, itemID

 while #arg > 0 do
  cur = string.sub(arg, 1, 1)
  arg = string.sub(arg, 2, #arg)
  if lastcur == "^" then
   if cur == "C" then
	name = read(arg)
	if not t[name] then t[name] = { {}, {}, {} } end
   elseif cur == "D" then
    diff = tonumber(read(arg))
	if not t[name][diff].lists then t[name][diff].lists = { {}, {}, {} } end
	if not t[name][diff].looted then t[name][diff].looted = {} end
   elseif cur == "L" then
    list = tonumber(read(arg))
	wipe(t[name][diff].lists[list])
   elseif cur == "I" then -- list itemID
    table.insert(t[name][diff].lists[list], tonumber(read(arg)))
   elseif cur == "J" then -- looted itemID
    itemID = tonumber(read(arg))
    t[name][diff].looted[itemID] = {}
   elseif cur == "K" then -- looted link
    t[name][diff].looted[itemID].link = read(arg)
   elseif cur == "T" then -- looted time
    t[name][diff].looted[itemID].time = tonumber(read(arg))
   elseif cur == "P" then -- personal loot flag
    t[name][diff].looted[itemID].personal = true
   end
  end
  lastcur = cur
 end
end